<?php
/**
 * Features Customizer options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */


// Add features enable section
$wp_customize->add_section( 'kids_education_pro_features_section', array(
	'title'             => esc_html__( 'Features','kids-education-pro' ),
	'description'       => esc_html__( 'Features section options.', 'kids-education-pro' ),
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add features enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_enable]', array(
	'default'           => $options['features_enable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[features_enable]', array(
	'label'             => esc_html__( 'Enable on', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_features_section',
	'type'              => 'select',
	'choices'           => kids_education_pro_enable_disable_options()
) );

// Show features section title setting and control
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_section_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'           => $options['features_section_title'],
	'transport'         => 'postMessage'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[features_section_title]', array(
	'label'           => esc_html__( 'Section Title', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_features_section',
	'active_callback' => 'kids_education_pro_is_features_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[features_section_title]', array(
		'selector'            => '#features h2.entry-title',
		'render_callback'     => 'kids_education_pro_customize_partial_features_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Show features section description setting and control
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_section_description]', array(
	'sanitize_callback' => 'esc_textarea',
	'default'           => $options['features_section_description'],
	'transport'         => 'postMessage'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[features_section_description]', array(
	'label'           => esc_html__( 'Section Description', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_features_section',
	'active_callback' => 'kids_education_pro_is_features_active',
	'type'            => 'textarea'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[features_section_description]', array(
		'selector'            => '#features p.sub-title',
		'render_callback'     => 'kids_education_pro_customize_partial_features_subtitle',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add features content layout setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_section_layout]', array(
	'default'           => $options['features_section_layout'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[features_section_layout]', array(
	'label'           	=> esc_html__( 'Select Layout', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_features_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_features_active',
	'choices'         	=> array(
		'three-columns'	=> esc_html__( 'Three Columns', 'kids-education-pro'),
		'four-columns'	=> esc_html__( 'Four Columns','kids-education-pro'),
	)
) );

//Excerpt length setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[excerpt_length]', array(
	'default'			=> $options['excerpt_length'],
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range',
	'validate_callback' => 'kids_education_pro_validate_excerpt',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[excerpt_length]', array(
	'label'       => esc_html__( 'Excerpt Length', 'kids-education-pro' ),
	'description' => esc_html__( 'Total words to be displayed in features section.', 'kids-education-pro' ),
	'section'     => 'kids_education_pro_features_section',
	'type'        => 'number',
	'active_callback' 	=> 'kids_education_pro_is_features_active',
	'input_attrs' => array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Add features content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_section_type]', array(
	'default'           => $options['features_section_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[features_section_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_features_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_features_active',
	'choices'         	=> array(
		'demo'			=> esc_html__( 'Demo','kids-education-pro'),
		'page'			=> esc_html__( 'Page', 'kids-education-pro'),
		'category'		=> esc_html__( 'Category', 'kids-education-pro'),
	)
) );

// Add features count setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_count]', array(
	'default'           => $options['features_count'],
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[features_count]', array(
	'label'           => esc_html__( 'Number of features.', 'kids-education-pro' ),
	'description'     => esc_html__( 'Notice: Please refresh after the number of features is modified to view changes.', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_features_section',
	'type'            => 'number',
	'active_callback' => 'kids_education_pro_is_features_content_demo_inactive',
	'input_attrs'     => array(
		'max' 		  => 12,
		'min' 		  => 1
	)
) );

for ( $i=1; $i <= $options['features_count']; $i++ ) {
	// Show features icon setting and control
	$wp_customize->add_setting( 'kids_education_pro_theme_options[features_icon_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[features_icon_'.$i.']', array(
		'label'           => sprintf( esc_html__( 'Icon #%s', 'kids-education-pro' ), $i ),
		'section'         => 'kids_education_pro_features_section',
		'active_callback' => 'kids_education_pro_is_features_content_demo_inactive',
		'type'            => 'text',
		'input_attrs'     => array( 'placeholder' => esc_attr__( 'fa-archive','kids-education-pro' ), ),
	) );

	// Show features count setting and control
	$wp_customize->add_setting( 'kids_education_pro_theme_options[features_page_id_'.$i.']', array(
		'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[features_page_id_'.$i.']', array(
		'label'           => sprintf( esc_html__( 'Select Page #%s', 'kids-education-pro' ), $i ),
		'section'         => 'kids_education_pro_features_section',
		'active_callback' => 'kids_education_pro_is_features_content_type_page_active',
		'type'            => 'dropdown-pages',
	) );

	// Show hr line setting and control
	$wp_customize->add_setting( 'kids_education_pro_theme_options[features_page_hr_'.$i.']', array(
		'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( new Kids_Education_Pro_Customize_Horizontal_Line ( $wp_customize, 'kids_education_pro_theme_options[features_page_hr_'.$i.']', array(
		'section'         => 'kids_education_pro_features_section',
		'active_callback' => 'kids_education_pro_is_features_content_type_page_active',
		'type'            => 'hr',
	) ) );
}

// Add features section category drop-down setting and control
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_dropdown_categories]', array(
	'default'			=> $options['features_dropdown_categories'],			
	'sanitize_callback'	=> 'kids_education_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Kids_Education_Pro_Dropdown_Category_Control( $wp_customize, 'kids_education_pro_theme_options[features_dropdown_categories]', array(
	'active_callback' 	=> 'kids_education_pro_is_features_content_type_as_category',
	'label'           	=> esc_html__( 'Select Category', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_features_section',
	'type'            	=> 'dropdown-category',
 ) ) );

// Add background property setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_background_property]', array(
	'default'           => $options['features_background_property'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[features_background_property]', array(
	'label'           	=> esc_html__( 'Select background property', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_features_section',
	'active_callback' 	=> 'kids_education_pro_is_features_content_demo_inactive',
	'type'				=> 'select',
	'choices'			=> array(
		'background_image' => esc_html__( 'Background Image', 'kids-education-pro' ),
		'background_color' => esc_html__( 'Background Color', 'kids-education-pro' ), 
	)
) );

// Add background image setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_background_image]', array(
	'default'           => $options['features_background_image'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[features_background_image]',
    array(
		'label'           => esc_html__( 'Upload a background image', 'kids-education-pro' ),
		'description'     => esc_html__( 'Recommended background image size is 1920x420 px', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_features_section',
		'active_callback' => 'kids_education_pro_is_features_background_property_image',
   )
));

// Add background color setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[features_background_color]', array(
	'default'           => $options['features_background_color'],
	'sanitize_callback' => 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[features_background_color]', array(
	'label'        => esc_html__( 'Background Color', 'kids-education-pro' ),
	'section'    => 'kids_education_pro_features_section',
	'active_callback' => 'kids_education_pro_is_features_background_property_color',
) ) );
